import cv2
import numpy as np
from keras.models import load_model

class prediction:
    def predict(self,image):
        model = load_model('/pneumonia_pkg/cnn_model_xray_vgg16.h5')
        image1 = cv2.resize(image, (224,224))
        image1 = np.array(image1)
        image2 = np.reshape(image1,(1, 224, 224, 3))
        pred = model.predict(image2)
        if pred<0.5:
            label = "Negative"
        else:
            label = "Positive"
        cv2.putText(image1, label,(0,30),cv2.FONT_HERSHEY_SIMPLEX,0.75,(255,0,0),2)
        return(image1,label)
        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Oct 29 15:54:21 2020

@author: advait_t
"""
from distutils.core import setup
setup(
  name = 'pneumonia_pkg',         
  packages = ['pneumonia_pkg'],   
  version = '3.0',      
  license='MIT',        
  description = 'tool for detecting pneumonia',  
  author = 'Advait Thergaonkar, Jay Prajapati',                   
  author_email = 'advait.thergaonkar60@nmims.edu.in',     
  url = 'https://github.com/advait-t/pneumonia_package', 
  download_url = 'https://github.com/advait-t/pneumonia_package/archive/3.0.tar.gz',  
  keywords = ['image', 'preprocessing', 'reshape','resize','background'],  
  install_requires=[            
          'validators',
          'beautifulsoup4'
          ,'numpy','pandas','opencv-python','matplotlib'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',     
    'Intended Audience :: Developers',     
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License', 
    'Programming Language :: Python :: 3',    
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)